import torch
from torch import nn
import torch.nn.functional as F

class CNN(nn.Module):
    def __init__(self):
        super(CNN, self).__init__()
        self.c1 = nn.Conv2d(1, 6, 5)
        self.c2 = nn.Conv2d(6, 16, 5)
        self.fc1 = nn.Linear(16 * 4 * 4, 120)
        self.fc2 = nn.Linear(120, 84)
        self.fc3 = nn.Linear(84, 10)
        
    def forward(self, X):
        X = F.max_pool2d(F.relu(self.c1(X)), 2)
        X = F.max_pool2d(F.relu(self.c2(X)), 2)
        X = X.view(-1, 16 * 4 * 4)
        X = F.relu(self.fc1(X))
        X = F.relu(self.fc2(X))
        X = self.fc3(X)
        return X

model = torch.load("model.pth")

import cv2 as cv

def transfer(path):
    img = cv.imread(path, cv.IMREAD_GRAYSCALE)
    img = cv.resize(img, (28, 28))
    data = torch.tensor(img, dtype=torch.float)
    return data

def predict(path):
    image = transfer(path)
    inputs = torch.reshape(image, [1, 28, 28]).cuda()
    outputs = model(inputs).cpu() 
    predicts = torch.max(outputs, 1).indices.item()
    return predicts




from flask import Flask, render_template, request
import base64

app = Flask(__name__)

@app.route("/")
def Index():
    return render_template("index.html")

@app.route("/predict", methods=["POST"])
def Predict():
    dataurl = str(request.get_data())
    dataurl = dataurl[24:len(dataurl) - 1]
    data = base64.b64decode(dataurl)
    with open("temp.jpg", "+wb") as img:
        img.write(data)
    result = predict("temp.jpg")
    return str(result)

if __name__ == "__main__":
    app.run("127.0.0.1", 5500)